@@ -24,6 +24,8 @@
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 # Copyright 2024 iarspider <iarspider@gmail.com>                               #
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2025 xmo-odoo <xmo@odoo.com>                                       #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -47,6 +49,7 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any
 
+import github.Branch
 import github.CheckRun
 import github.CheckSuite
 import github.CommitCombinedStatus
@@ -57,10 +60,12 @@ import github.File
 import github.GitCommit
 import github.NamedUser
 import github.PaginatedList
+import github.Repository
 from github.GithubObject import Attribute, CompletableGithubObject, NotSet, Opt, is_optional
 from github.PaginatedList import PaginatedList
 
 if TYPE_CHECKING:
+    from github.Branch import Branch
     from github.CheckRun import CheckRun
     from github.CheckSuite import CheckSuite
     from github.CommitCombinedStatus import CommitCombinedStatus
@@ -71,6 +76,7 @@ if TYPE_CHECKING:
     from github.GitCommit import GitCommit
     from github.NamedUser import NamedUser
     from github.PullRequest import PullRequest
+    from github.Repository import Repository
 
 
 class Commit(CompletableGithubObject):
@@ -78,7 +84,16 @@ class Commit(CompletableGithubObject):
     This class represents Commits.
 
     The reference can be found here
-    https://docs.github.com/en/rest/reference/git#commits
+    https://docs.github.com/en/rest/commits/commits#get-a-commit-object
+
+    The OpenAPI schema can be found at
+
+    - /components/schemas/branch-short/properties/commit
+    - /components/schemas/commit
+    - /components/schemas/commit-search-result-item/properties/parents/items
+    - /components/schemas/commit/properties/parents/items
+    - /components/schemas/short-branch/properties/commit
+    - /components/schemas/tag/properties/commit
 
     """
 
@@ -87,15 +102,23 @@ class Commit(CompletableGithubObject):
         self._comments_url: Attribute[str] = NotSet
         self._commit: Attribute[GitCommit] = NotSet
         self._committer: Attribute[NamedUser] = NotSet
+        self._files: Attribute[list[File]] = NotSet
         self._html_url: Attribute[str] = NotSet
+        self._node_id: Attribute[str] = NotSet
         self._parents: Attribute[list[Commit]] = NotSet
+        self._repository: Attribute[Repository] = NotSet
         self._sha: Attribute[str] = NotSet
         self._stats: Attribute[CommitStats] = NotSet
+        self._text_matches: Attribute[dict[str, Any]] = NotSet
         self._url: Attribute[str] = NotSet
 
     def __repr__(self) -> str:
         return self.get__repr__({"sha": self._sha.value})
 
+    @property
+    def _identity(self) -> str:
+        return self.sha
+
     @property
     def author(self) -> NamedUser:
         self._completeIfNotSet(self._author)
@@ -137,11 +160,21 @@ class Commit(CompletableGithubObject):
         self._completeIfNotSet(self._html_url)
         return self._html_url.value
 
+    @property
+    def node_id(self) -> str:
+        self._completeIfNotSet(self._node_id)
+        return self._node_id.value
+
     @property
     def parents(self) -> list[Commit]:
         self._completeIfNotSet(self._parents)
         return self._parents.value
 
+    @property
+    def repository(self) -> Repository:
+        self._completeIfNotSet(self._repository)
+        return self._repository.value
+
     @property
     def sha(self) -> str:
         self._completeIfNotSet(self._sha)
@@ -152,6 +185,11 @@ class Commit(CompletableGithubObject):
         self._completeIfNotSet(self._stats)
         return self._stats.value
 
+    @property
+    def text_matches(self) -> dict[str, Any]:
+        self._completeIfNotSet(self._text_matches)
+        return self._text_matches.value
+
     @property
     def url(self) -> str:
         self._completeIfNotSet(self._url)
@@ -204,7 +242,14 @@ class Commit(CompletableGithubObject):
             f"{self._parentUrl(self._parentUrl(self.url))}/statuses/{self.sha}",
             input=post_parameters,
         )
-        return github.CommitStatus.CommitStatus(self._requester, headers, data, completed=True)
+        return github.CommitStatus.CommitStatus(self._requester, headers, data)
+
+    def get_branches_where_head(self) -> list[Branch]:
+        """
+        :calls: `GET /repos/{owner}/{repo}/commits/{commit_sha}/branches-where-head <https://docs.github.com/rest/commits/commits#list-branches-for-head-commit>`_
+        """
+        headers, data = self._requester.requestJsonAndCheck("GET", f"{self.url}/branches-where-head")
+        return [github.Branch.Branch(self._requester, headers, item) for item in data]
 
     def get_comments(self) -> PaginatedList[CommitComment]:
         """
@@ -233,7 +278,7 @@ class Commit(CompletableGithubObject):
         :calls: `GET /repos/{owner}/{repo}/commits/{ref}/status/ <http://docs.github.com/en/rest/reference/repos#statuses>`_
         """
         headers, data = self._requester.requestJsonAndCheck("GET", f"{self.url}/status")
-        return github.CommitCombinedStatus.CommitCombinedStatus(self._requester, headers, data, completed=True)
+        return github.CommitCombinedStatus.CommitCombinedStatus(self._requester, headers, data)
 
     def get_pulls(self) -> PaginatedList[PullRequest]:
         """
@@ -288,10 +333,6 @@ class Commit(CompletableGithubObject):
             list_item="check_suites",
         )
 
-    @property
-    def _identity(self) -> str:
-        return self.sha
-
     def _useAttributes(self, attributes: dict[str, Any]) -> None:
         if "author" in attributes:  # pragma no branch
             self._author = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["author"])
@@ -301,13 +342,52 @@ class Commit(CompletableGithubObject):
             self._commit = self._makeClassAttribute(github.GitCommit.GitCommit, attributes["commit"])
         if "committer" in attributes:  # pragma no branch
             self._committer = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["committer"])
+        if "files" in attributes:  # pragma no branch
+            self._files = self._makeListOfClassesAttribute(github.File.File, attributes["files"])
         if "html_url" in attributes:  # pragma no branch
             self._html_url = self._makeStringAttribute(attributes["html_url"])
+        if "node_id" in attributes:  # pragma no branch
+            self._node_id = self._makeStringAttribute(attributes["node_id"])
         if "parents" in attributes:  # pragma no branch
             self._parents = self._makeListOfClassesAttribute(Commit, attributes["parents"])
+        if "repository" in attributes:  # pragma no branch
+            self._repository = self._makeClassAttribute(github.Repository.Repository, attributes["repository"])
         if "sha" in attributes:  # pragma no branch
             self._sha = self._makeStringAttribute(attributes["sha"])
         if "stats" in attributes:  # pragma no branch
             self._stats = self._makeClassAttribute(github.CommitStats.CommitStats, attributes["stats"])
+        if "text_matches" in attributes:  # pragma no branch
+            self._text_matches = self._makeDictAttribute(attributes["text_matches"])
         if "url" in attributes:  # pragma no branch
             self._url = self._makeStringAttribute(attributes["url"])
+
+
+class CommitSearchResult(Commit):
+    """
+    This class represents CommitSearchResult.
+
+    The reference can be found here
+    https://docs.github.com/en/rest/reference/search#search-commits
+
+    The OpenAPI schema can be found at
+
+    - /components/schemas/commit-search-result-item
+
+    """
+
+    def _initAttributes(self) -> None:
+        super()._initAttributes()
+        self._score: Attribute[float] = NotSet
+
+    def __repr__(self) -> str:
+        return self.get__repr__({"sha": self._sha.value, "score": self._score.value})
+
+    @property
+    def score(self) -> float:
+        self._completeIfNotSet(self._score)
+        return self._score.value
+
+    def _useAttributes(self, attributes: dict[str, Any]) -> None:
+        super()._useAttributes(attributes)
+        if "score" in attributes:  # pragma no branch
+            self._score = self._makeFloatAttribute(attributes["score"])
