@@ -29,6 +29,7 @@
 # Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
 # Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
 # Copyright 2024 Min RK <benjaminrk@gmail.com>                                 #
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -48,15 +49,18 @@
 #                                                                              #
 ################################################################################
 
+from __future__ import annotations
+
 import email.utils
 import re
 import typing
+from abc import ABC
 from datetime import datetime, timezone
 from decimal import Decimal
 from operator import itemgetter
-from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Tuple, Type, Union, overload
+from typing import TYPE_CHECKING, Any, Callable, Union, overload
 
-from typing_extensions import Protocol, TypeGuard
+from typing_extensions import Protocol, Self, TypeGuard
 
 from . import Consts
 from .GithubException import BadAttributeException, IncompletableObject
@@ -107,7 +111,7 @@ def _datetime_from_github_isoformat(value: str) -> datetime:
     return datetime.fromisoformat(value)
 
 
-class _NotSetType:
+class _NotSetType(Attribute[Any]):
     def __repr__(self) -> str:
         return "NotSet"
 
@@ -116,7 +120,7 @@ class _NotSetType:
         return None
 
     @staticmethod
-    def remove_unset_items(data: Dict[str, Any]) -> Dict[str, Any]:
+    def remove_unset_items(data: dict[str, Any]) -> dict[str, Any]:
         return {key: value for key, value in data.items() if not isinstance(value, _NotSetType)}
 
 
@@ -125,19 +129,19 @@ NotSet = _NotSetType()
 Opt = Union[T, _NotSetType]
 
 
-def is_defined(v: Union[T, _NotSetType]) -> TypeGuard[T]:
+def is_defined(v: T | _NotSetType) -> TypeGuard[T]:
     return not isinstance(v, _NotSetType)
 
 
-def is_undefined(v: Union[T, _NotSetType]) -> TypeGuard[_NotSetType]:
+def is_undefined(v: T | _NotSetType) -> TypeGuard[_NotSetType]:
     return isinstance(v, _NotSetType)
 
 
-def is_optional(v: Any, type: Union[Type, Tuple[Type, ...]]) -> bool:
+def is_optional(v: Any, type: type | tuple[type, ...]) -> bool:
     return isinstance(v, _NotSetType) or isinstance(v, type)
 
 
-def is_optional_list(v: Any, type: Union[Type, Tuple[Type, ...]]) -> bool:
+def is_optional_list(v: Any, type: type | tuple[type, ...]) -> bool:
     return isinstance(v, _NotSetType) or isinstance(v, list) and all(isinstance(element, type) for element in v)
 
 
@@ -145,7 +149,7 @@ camel_to_snake_case_regexp = re.compile(r"(?<!^)(?=[A-Z])")
 
 
 @overload
-def as_rest_api_attributes(graphql_attributes: Dict[str, Any]) -> Dict[str, Any]:
+def as_rest_api_attributes(graphql_attributes: dict[str, Any]) -> dict[str, Any]:
     ...
 
 
@@ -154,7 +158,7 @@ def as_rest_api_attributes(graphql_attributes: None) -> None:
     ...
 
 
-def as_rest_api_attributes(graphql_attributes: Optional[Dict[str, Any]]) -> Optional[Dict[str, Any]]:
+def as_rest_api_attributes(graphql_attributes: dict[str, Any] | None) -> dict[str, Any] | None:
     """
     Converts attributes from GraphQL schema to REST API schema.
 
@@ -193,7 +197,7 @@ def as_rest_api_attributes(graphql_attributes: Optional[Dict[str, Any]]) -> Opti
     }
 
 
-def as_rest_api_attributes_list(graphql_attributes: List[Optional[Dict[str, Any]]]) -> List[Optional[Dict[str, Any]]]:
+def as_rest_api_attributes_list(graphql_attributes: list[dict[str, Any] | None]) -> list[dict[str, Any] | None]:
     return [as_rest_api_attributes(v) if isinstance(v, dict) else v for v in graphql_attributes]
 
 
@@ -206,20 +210,20 @@ class _ValuedAttribute(Attribute[T]):
         return self._value
 
 
-class _BadAttribute(Attribute):
-    def __init__(self, value: Any, expectedType: Any, exception: Optional[Exception] = None):
+class _BadAttribute(Attribute[T]):
+    def __init__(self, value: Any, expectedType: Any, exception: Exception | None = None):
         self.__value = value
         self.__expectedType = expectedType
         self.__exception = exception
 
     @property
-    def value(self) -> Any:
+    def value(self) -> T:
         raise BadAttributeException(self.__value, self.__expectedType, self.__exception)
 
 
 # v3: add * to edit function of all GithubObject implementations,
 #     this allows to rename attributes and maintain the order of attributes
-class GithubObject:
+class GithubObject(ABC):
     """
     Base class for all classes representing objects returned by the API.
     """
@@ -244,10 +248,9 @@ class GithubObject:
 
     def __init__(
         self,
-        requester: "Requester",
-        headers: Dict[str, Union[str, int]],
+        requester: Requester,
+        headers: dict[str, str | int],
         attributes: Any,
-        completed: bool,
     ):
         self._requester = requester
         self._initAttributes()
@@ -258,7 +261,7 @@ class GithubObject:
         if self.CHECK_AFTER_INIT_FLAG:  # pragma no branch (Flag always set in tests)
             requester.check_me(self)
 
-    def _storeAndUseAttributes(self, headers: Dict[str, Union[str, int]], attributes: Any) -> None:
+    def _storeAndUseAttributes(self, headers: dict[str, str | int], attributes: Any) -> None:
         # Make sure headers are assigned before calling _useAttributes
         # (Some derived classes will use headers in _useAttributes)
         self._headers = headers
@@ -266,7 +269,7 @@ class GithubObject:
         self._useAttributes(attributes)
 
     @property
-    def requester(self) -> "Requester":
+    def requester(self) -> Requester:
         """
         Return my Requester object.
 
@@ -276,19 +279,17 @@ class GithubObject:
         return self._requester
 
     @property
-    def raw_data(self) -> Dict[str, Any]:
+    def raw_data(self) -> dict[str, Any]:
         """
         :type: dict
         """
-        self._completeIfNeeded()
         return self._rawData
 
     @property
-    def raw_headers(self) -> Dict[str, Union[str, int]]:
+    def raw_headers(self) -> dict[str, str | int]:
         """
         :type: dict
         """
-        self._completeIfNeeded()
         return self._headers
 
     @staticmethod
@@ -296,21 +297,21 @@ class GithubObject:
         return "/".join(url.split("/")[:-1])
 
     @staticmethod
-    def __makeSimpleAttribute(value: Any, type: Type[T]) -> Attribute[T]:
+    def __makeSimpleAttribute(value: Any, type: type[T]) -> Attribute[T]:
         if value is None or isinstance(value, type):
             return _ValuedAttribute(value)  # type: ignore
         else:
             return _BadAttribute(value, type)  # type: ignore
 
     @staticmethod
-    def __makeSimpleListAttribute(value: list, type: Type[T]) -> Attribute[T]:
+    def __makeSimpleListAttribute(value: list, type: type[T]) -> Attribute[T]:
         if isinstance(value, list) and all(isinstance(element, type) for element in value):
             return _ValuedAttribute(value)  # type: ignore
         else:
             return _BadAttribute(value, [type])  # type: ignore
 
     @staticmethod
-    def __makeTransformedAttribute(value: T, type: Type[T], transform: Callable[[T], K]) -> Attribute[K]:
+    def __makeTransformedAttribute(value: T, type: type[T], transform: Callable[[T], K]) -> Attribute[K]:
         if value is None:
             return _ValuedAttribute(None)  # type: ignore
         elif isinstance(value, type):
@@ -322,27 +323,27 @@ class GithubObject:
             return _BadAttribute(value, type)  # type: ignore
 
     @staticmethod
-    def _makeStringAttribute(value: Optional[Union[int, str]]) -> Attribute[str]:
+    def _makeStringAttribute(value: int | str | None) -> Attribute[str]:
         return GithubObject.__makeSimpleAttribute(value, str)
 
     @staticmethod
-    def _makeIntAttribute(value: Optional[Union[int, str]]) -> Attribute[int]:
+    def _makeIntAttribute(value: int | str | None) -> Attribute[int]:
         return GithubObject.__makeSimpleAttribute(value, int)
 
     @staticmethod
-    def _makeDecimalAttribute(value: Optional[Decimal]) -> Attribute[Decimal]:
+    def _makeDecimalAttribute(value: Decimal | None) -> Attribute[Decimal]:
         return GithubObject.__makeSimpleAttribute(value, Decimal)
 
     @staticmethod
-    def _makeFloatAttribute(value: Optional[float]) -> Attribute[float]:
+    def _makeFloatAttribute(value: float | None) -> Attribute[float]:
         return GithubObject.__makeSimpleAttribute(value, float)
 
     @staticmethod
-    def _makeBoolAttribute(value: Optional[bool]) -> Attribute[bool]:
+    def _makeBoolAttribute(value: bool | None) -> Attribute[bool]:
         return GithubObject.__makeSimpleAttribute(value, bool)
 
     @staticmethod
-    def _makeDictAttribute(value: Dict[str, Any]) -> Attribute[Dict[str, Any]]:
+    def _makeDictAttribute(value: dict[str, Any]) -> Attribute[dict[str, Any]]:
         return GithubObject.__makeSimpleAttribute(value, dict)
 
     @staticmethod
@@ -354,92 +355,135 @@ class GithubObject:
         )
 
     @staticmethod
-    def _makeDatetimeAttribute(value: Optional[str]) -> Attribute[datetime]:
+    def _makeDatetimeAttribute(value: str | None) -> Attribute[datetime]:
         return GithubObject.__makeTransformedAttribute(value, str, _datetime_from_github_isoformat)  # type: ignore
 
     @staticmethod
-    def _makeHttpDatetimeAttribute(value: Optional[str]) -> Attribute[datetime]:
+    def _makeHttpDatetimeAttribute(value: str | None) -> Attribute[datetime]:
         return GithubObject.__makeTransformedAttribute(value, str, _datetime_from_http_date)  # type: ignore
 
-    def _makeClassAttribute(self, klass: Type[T_gh], value: Any) -> Attribute[T_gh]:
+    def _makeClassAttribute(self, klass: type[T_gh], value: Any) -> Attribute[T_gh]:
         return GithubObject.__makeTransformedAttribute(
             value,
             dict,
-            lambda value: klass(self._requester, self._headers, value, completed=False),
+            lambda value: klass(self._requester, self._headers, value),
+        )
+
+    def _makeUnionClassAttributeFromTypeName(
+        self, type_name: str | None, fallback_type: str | None, value: Any, *class_and_names: tuple[type[T_gh], str]
+    ) -> Attribute[T_gh]:
+        if value is None or type_name is None:
+            return _ValuedAttribute(None)  # type: ignore
+        fallback_class = None
+        for klass, name in class_and_names:
+            if type_name == name:
+                return self._makeClassAttribute(klass, value)
+            if fallback_type == name:
+                fallback_class = klass
+        if fallback_type is not None:
+            if fallback_class is None:
+                # this is misconfiguration in PyGithub code, not a user's fault
+                raise ValueError(
+                    f"Fallback type {fallback_type} is not among classes and names: {[name for klass, name in class_and_names]}"
+                )
+            return self._makeClassAttribute(fallback_class, value)
+        return _BadAttribute(value, type)  # type: ignore
+
+    def _makeUnionClassAttributeFromTypeKey(
+        self,
+        type_key: str,
+        default_type: str | None,
+        value: Any,
+        *class_and_names: tuple[type[T_gh], str],
+    ) -> Attribute[T_gh]:
+        if value is None or not isinstance(value, dict):
+            return _ValuedAttribute(None)  # type: ignore
+        return self._makeUnionClassAttributeFromTypeName(
+            value.get(type_key, default_type), default_type, value, *class_and_names
+        )
+
+    def _makeUnionClassAttributeFromTypeKeyAndValueKey(
+        self,
+        type_key: str,
+        value_key: str,
+        default_type: str | None,
+        value: Any,
+        *class_and_names: tuple[type[T_gh], str],
+    ) -> Attribute[T_gh]:
+        if value is None or not isinstance(value, dict):
+            return _ValuedAttribute(None)  # type: ignore
+        return self._makeUnionClassAttributeFromTypeName(
+            value.get(type_key, default_type), default_type, value.get(value_key), *class_and_names
         )
 
     @staticmethod
-    def _makeListOfStringsAttribute(value: Union[List[List[str]], List[str], List[Union[str, int]]]) -> Attribute:
+    def _makeListOfStringsAttribute(value: list[list[str]] | list[str] | list[str | int]) -> Attribute:
         return GithubObject.__makeSimpleListAttribute(value, str)
 
     @staticmethod
-    def _makeListOfIntsAttribute(value: List[int]) -> Attribute:
+    def _makeListOfIntsAttribute(value: list[int]) -> Attribute:
         return GithubObject.__makeSimpleListAttribute(value, int)
 
     @staticmethod
-    def _makeListOfDictsAttribute(
-        value: List[Dict[str, Union[str, List[Dict[str, Union[str, List[int]]]]]]]
-    ) -> Attribute:
+    def _makeListOfDictsAttribute(value: list[dict[str, str | list[dict[str, str | list[int]]]]]) -> Attribute:
         return GithubObject.__makeSimpleListAttribute(value, dict)
 
     @staticmethod
     def _makeListOfListOfStringsAttribute(
-        value: List[List[str]],
+        value: list[list[str]],
     ) -> Attribute:
         return GithubObject.__makeSimpleListAttribute(value, list)
 
-    def _makeListOfClassesAttribute(self, klass: Type[T_gh], value: Any) -> Attribute[List[T_gh]]:
+    def _makeListOfClassesAttribute(self, klass: type[T_gh], value: Any) -> Attribute[list[T_gh]]:
         if isinstance(value, list) and all(isinstance(element, dict) for element in value):
-            return _ValuedAttribute(
-                [klass(self._requester, self._headers, element, completed=False) for element in value]
-            )
+            return _ValuedAttribute([klass(self._requester, self._headers, element) for element in value])
         else:
             return _BadAttribute(value, [dict])
 
     def _makeDictOfStringsToClassesAttribute(
         self,
-        klass: Type[T_gh],
-        value: Dict[
+        klass: type[T_gh],
+        value: dict[
             str,
-            Union[int, Dict[str, Union[str, int, None]], Dict[str, Union[str, int]]],
+            int | dict[str, Any],
         ],
-    ) -> Attribute[Dict[str, T_gh]]:
+    ) -> Attribute[dict[str, T_gh]]:
         if isinstance(value, dict) and all(
             isinstance(key, str) and isinstance(element, dict) for key, element in value.items()
         ):
             return _ValuedAttribute(
-                {key: klass(self._requester, self._headers, element, completed=False) for key, element in value.items()}
+                {key: klass(self._requester, self._headers, element) for key, element in value.items()}
             )
         else:
             return _BadAttribute(value, {str: dict})
 
     @property
-    def etag(self) -> Optional[str]:
+    def etag(self) -> str | None:
         """
         :type: str
         """
         return self._headers.get(Consts.RES_ETAG)  # type: ignore
 
     @property
-    def last_modified(self) -> Optional[str]:
+    def last_modified(self) -> str | None:
         """
         :type: str
         """
         return self._headers.get(Consts.RES_LAST_MODIFIED)  # type: ignore
 
     @property
-    def last_modified_datetime(self) -> Optional[datetime]:
+    def last_modified_datetime(self) -> datetime | None:
         """
         :type: datetime
         """
         return self._makeHttpDatetimeAttribute(self.last_modified).value  # type: ignore
 
-    def get__repr__(self, params: Dict[str, Any]) -> str:
+    def get__repr__(self, params: dict[str, Any]) -> str:
         """
         Converts the object to a nicely printable string.
         """
 
-        def format_params(params: Dict[str, Any]) -> typing.Generator[str, None, None]:
+        def format_params(params: dict[str, Any]) -> typing.Generator[str, None, None]:
             items = list(params.items())
             for k, v in sorted(items, key=itemgetter(0), reverse=True):
                 if isinstance(v, bytes):
@@ -459,9 +503,6 @@ class GithubObject:
     def _useAttributes(self, attributes: Any) -> None:
         raise NotImplementedError("BUG: Not Implemented _useAttributes")
 
-    def _completeIfNeeded(self) -> None:
-        raise NotImplementedError("BUG: Not Implemented _completeIfNeeded")
-
 
 class GraphQlObject:
     @classmethod
@@ -469,21 +510,63 @@ class GraphQlObject:
         return True
 
 
-class NonCompletableGithubObject(GithubObject):
-    def _completeIfNeeded(self) -> None:
-        pass
-
-
-class CompletableGithubObject(GithubObject):
+class NonCompletableGithubObject(GithubObject, ABC):
     def __init__(
         self,
-        requester: "Requester",
-        headers: Dict[str, Union[str, int]],
-        attributes: Dict[str, Any],
-        completed: bool,
+        requester: Requester,
+        headers: dict[str, str | int],
+        attributes: dict[str, Any],
     ):
-        super().__init__(requester, headers, attributes, completed)
-        self.__completed = completed
+        super().__init__(requester, headers, attributes)
+
+
+class CompletableGithubObject(GithubObject, ABC):
+    def __init__(
+        self,
+        requester: Requester,
+        headers: dict[str, str | int] | None = None,
+        attributes: dict[str, Any] | None = None,
+        completed: bool | None = None,
+        *,
+        url: str | None = None,
+        accept: str | None = None,
+    ):
+        """
+        A CompletableGithubObject can be partially initialised (completed=False). Accessing attributes that are not
+        initialized will then trigger a request to complete all attributes.
+
+        A partially initialized CompletableGithubObject (completed=False) can be completed
+        via complete(). This requires the url to be given via parameter `url` or `attributes`.
+
+        With a requester where `Requester.is_lazy == True`, this CompletableGithubObjects is
+        partially initialized. This requires the url to be given via parameter `url` or `attributes`.
+        Any CompletableGithubObject created from this lazy object will be lazy itself if created with
+        parameter `url` or `attributes`.
+
+        :param requester: requester
+        :param headers: response headers
+        :param attributes: attributes to initialize
+        :param completed: do not update non-initialized attributes when True
+        :param url: url of this instance, overrides attributes['url']
+        :param accept: use this accept header when completing this instance
+
+        """
+        response_given = headers is not None or attributes is not None
+
+        if headers is None:
+            headers = {}
+        if attributes is None:
+            attributes = {}
+        if url is not None:
+            attributes["url"] = url
+        super().__init__(requester, headers, attributes)
+        self.__completed = completed if isinstance(completed, bool) else False
+        self.__completeHeaders = {"Accept": accept} if accept else None
+
+        # complete this completable object when requester indicates non-laziness and
+        # neither of complete, headers and attributes are given
+        if requester.is_not_lazy and completed is None and not response_given:
+            self.complete()
 
     def __eq__(self, other: Any) -> bool:
         return other.__class__ is self.__class__ and other._url.value == self._url.value
@@ -494,6 +577,30 @@ class CompletableGithubObject(GithubObject):
     def __ne__(self, other: Any) -> bool:
         return not self == other
 
+    @property
+    def completed(self) -> bool:
+        return self.__completed
+
+    @property
+    def raw_data(self) -> dict[str, Any]:
+        """
+        :type: dict
+        """
+        self._completeIfNeeded()
+        return super().raw_data
+
+    @property
+    def raw_headers(self) -> dict[str, str | int]:
+        """
+        :type: dict
+        """
+        self._completeIfNeeded()
+        return super().raw_headers
+
+    def complete(self) -> Self:
+        self._completeIfNeeded()
+        return self
+
     def _completeIfNotSet(self, value: Attribute) -> None:
         if isinstance(value, _NotSetType):
             self._completeIfNeeded()
@@ -504,12 +611,12 @@ class CompletableGithubObject(GithubObject):
 
     def __complete(self) -> None:
         if self._url.value is None:
-            raise IncompletableObject(400, message="Returned object contains no URL")
-        headers, data = self._requester.requestJsonAndCheck("GET", self._url.value)
+            raise IncompletableObject(400, message="Cannot complete object as it contains no URL")
+        headers, data = self._requester.requestJsonAndCheck("GET", self._url.value, headers=self.__completeHeaders)
         self._storeAndUseAttributes(headers, data)
         self.__completed = True
 
-    def update(self, additional_headers: Optional[Dict[str, Any]] = None) -> bool:
+    def update(self, additional_headers: dict[str, Any] | None = None) -> bool:
         """
         Check and update the object with conditional request :rtype: Boolean value indicating whether the object is
         changed.
