@@ -1,6 +1,14 @@
 ############################ Copyrights and license ############################
 #                                                                              #
-# Copyright 2023 Jonathan Leitschuh <Jonathan.Leitschuh@gmail.com>             #
+# Copyright 2023 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2023 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2023 Jonathan Leitschuh <jonathan.leitschuh@gmail.com>             #
+# Copyright 2023 Joseph Henrich <crimsonknave@gmail.com>                       #
+# Copyright 2023 Trim21 <trim21.me@gmail.com>                                  #
+# Copyright 2024 Enrico Minack <github@enrico.minack.dev>                      #
+# Copyright 2024 Jirka Borovec <6035284+Borda@users.noreply.github.com>        #
+# Copyright 2024 Thomas Cooper <coopernetes@proton.me>                         #
+# Copyright 2025 Enrico Minack <github@enrico.minack.dev>                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
 # http://pygithub.readthedocs.io/                                              #
@@ -19,51 +27,59 @@
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
 ################################################################################
+
 from __future__ import annotations
 
 from datetime import datetime
 from typing import TYPE_CHECKING, Any, Iterable
 
+import github.AdvisoryCredit
+import github.AdvisoryCreditDetailed
+import github.AdvisoryVulnerability
 import github.NamedUser
-from github.CWE import CWE
-from github.GithubObject import Attribute, NonCompletableGithubObject, NotSet, Opt
-from github.RepositoryAdvisoryCredit import Credit, RepositoryAdvisoryCredit
-from github.RepositoryAdvisoryCreditDetailed import RepositoryAdvisoryCreditDetailed
-from github.RepositoryAdvisoryVulnerability import AdvisoryVulnerability, RepositoryAdvisoryVulnerability
+import github.Repository
+import github.Team
+from github.AdvisoryBase import AdvisoryBase
+from github.GithubObject import Attribute, NotSet, Opt
 
 if TYPE_CHECKING:
+    from github.AdvisoryCredit import AdvisoryCredit, Credit
+    from github.AdvisoryCreditDetailed import AdvisoryCreditDetailed
+    from github.AdvisoryVulnerability import AdvisoryVulnerability, AdvisoryVulnerabilityInput
     from github.NamedUser import NamedUser
+    from github.Repository import Repository
+    from github.Team import Team
 
 
-class RepositoryAdvisory(NonCompletableGithubObject):
+class RepositoryAdvisory(AdvisoryBase):
     """
     This class represents a RepositoryAdvisory.
-    The reference can be found here https://docs.github.com/en/rest/security-advisories/repository-advisories
+
+    The reference can be found here
+    https://docs.github.com/en/rest/security-advisories/repository-advisories
+
+    The OpenAPI schema can be found at
+
+    - /components/schemas/repository-advisory
+
     """
 
     def _initAttributes(self) -> None:
+        super()._initAttributes()
         self._author: Attribute[NamedUser] = NotSet
         self._closed_at: Attribute[datetime] = NotSet
+        self._collaborating_teams: Attribute[list[Team]] = NotSet
+        self._collaborating_users: Attribute[list[NamedUser]] = NotSet
         self._created_at: Attribute[datetime] = NotSet
-        self._credits: Attribute[list[RepositoryAdvisoryCredit]] = NotSet
-        self._credits_detailed: Attribute[list[RepositoryAdvisoryCreditDetailed]] = NotSet
-        self._cve_id: Attribute[str] = NotSet
+        self._credits: Attribute[list[AdvisoryCredit]] = NotSet
+        self._credits_detailed: Attribute[list[AdvisoryCreditDetailed]] = NotSet
         self._cwe_ids: Attribute[list[str]] = NotSet
-        self._cwes: Attribute[list[CWE]] = NotSet
-        self._description: Attribute[str] = NotSet
-        self._ghsa_id: Attribute[str] = NotSet
-        self._html_url: Attribute[str] = NotSet
-        self._published_at: Attribute[datetime] = NotSet
-        self._severity: Attribute[str] = NotSet
+        self._private_fork: Attribute[Repository] = NotSet
+        self._publisher: Attribute[NamedUser] = NotSet
         self._state: Attribute[str] = NotSet
-        self._summary: Attribute[str] = NotSet
-        self._updated_at: Attribute[datetime] = NotSet
-        self._url: Attribute[str] = NotSet
-        self._vulnerabilities: Attribute[list[RepositoryAdvisoryVulnerability]] = NotSet
-        self._withdrawn_at: Attribute[datetime] = NotSet
-
-    def __repr__(self) -> str:
-        return self.get__repr__({"ghsa_id": self.ghsa_id, "summary": self.summary})
+        self._submission: Attribute[dict[str, Any]] = NotSet
+        self._vulnerabilities: Attribute[list[AdvisoryVulnerability]] = NotSet
+        super()._initAttributes()
 
     @property
     def author(self) -> NamedUser:
@@ -73,6 +89,14 @@ class RepositoryAdvisory(NonCompletableGithubObject):
     def closed_at(self) -> datetime:
         return self._closed_at.value
 
+    @property
+    def collaborating_teams(self) -> list[Team]:
+        return self._collaborating_teams.value
+
+    @property
+    def collaborating_users(self) -> list[NamedUser]:
+        return self._collaborating_users.value
+
     @property
     def created_at(self) -> datetime:
         return self._created_at.value
@@ -80,71 +104,39 @@ class RepositoryAdvisory(NonCompletableGithubObject):
     @property
     def credits(
         self,
-    ) -> list[RepositoryAdvisoryCredit]:
+    ) -> list[AdvisoryCredit]:
         return self._credits.value
 
     @property
     def credits_detailed(
         self,
-    ) -> list[RepositoryAdvisoryCreditDetailed]:
+    ) -> list[AdvisoryCreditDetailed]:
         return self._credits_detailed.value
 
-    @property
-    def cve_id(self) -> str:
-        return self._cve_id.value
-
     @property
     def cwe_ids(self) -> list[str]:
         return self._cwe_ids.value
 
     @property
-    def cwes(self) -> list[CWE]:
-        return self._cwes.value
+    def private_fork(self) -> Repository:
+        return self._private_fork.value
 
     @property
-    def description(self) -> str:
-        return self._description.value
-
-    @property
-    def ghsa_id(self) -> str:
-        return self._ghsa_id.value
-
-    @property
-    def html_url(self) -> str:
-        return self._html_url.value
-
-    @property
-    def published_at(self) -> datetime:
-        return self._published_at.value
-
-    @property
-    def severity(self) -> str:
-        return self._severity.value
+    def publisher(self) -> NamedUser:
+        return self._publisher.value
 
     @property
     def state(self) -> str:
         return self._state.value
 
     @property
-    def summary(self) -> str:
-        return self._summary.value
+    def submission(self) -> dict[str, Any]:
+        return self._submission.value
 
     @property
-    def updated_at(self) -> datetime:
-        return self._updated_at.value
-
-    @property
-    def url(self) -> str:
-        return self._url.value
-
-    @property
-    def vulnerabilities(self) -> list[RepositoryAdvisoryVulnerability]:
+    def vulnerabilities(self) -> list[AdvisoryVulnerability]:
         return self._vulnerabilities.value
 
-    @property
-    def withdrawn_at(self) -> datetime:
-        return self._withdrawn_at.value
-
     def add_vulnerability(
         self,
         ecosystem: str,
@@ -170,19 +162,17 @@ class RepositoryAdvisory(NonCompletableGithubObject):
             ]
         )
 
-    def add_vulnerabilities(self, vulnerabilities: Iterable[AdvisoryVulnerability]) -> None:
+    def add_vulnerabilities(self, vulnerabilities: Iterable[AdvisoryVulnerabilityInput]) -> None:
         """
         :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
         """
         assert isinstance(vulnerabilities, Iterable), vulnerabilities
         for vulnerability in vulnerabilities:
-            github.RepositoryAdvisoryVulnerability.RepositoryAdvisoryVulnerability._validate_vulnerability(
-                vulnerability
-            )
+            github.AdvisoryVulnerability.AdvisoryVulnerability._validate_vulnerability(vulnerability)
 
         post_parameters = {
             "vulnerabilities": [
-                github.RepositoryAdvisoryVulnerability.RepositoryAdvisoryVulnerability._to_github_dict(vulnerability)
+                github.AdvisoryVulnerability.AdvisoryVulnerability._to_github_dict(vulnerability)
                 for vulnerability in (self.vulnerabilities + list(vulnerabilities))
             ]
         }
@@ -199,9 +189,11 @@ class RepositoryAdvisory(NonCompletableGithubObject):
         credit_type: str,
     ) -> None:
         """
-        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
         Offers credit to a user for a vulnerability in a repository.
+
         Unless you are giving credit to yourself, the user having credit offered will need to explicitly accept the credit.
+        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
+
         """
         self.offer_credits([{"login": login_or_user, "type": credit_type}])
 
@@ -210,17 +202,22 @@ class RepositoryAdvisory(NonCompletableGithubObject):
         credited: Iterable[Credit],
     ) -> None:
         """
-        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
         Offers credit to a list of users for a vulnerability in a repository.
+
         Unless you are giving credit to yourself, the user having credit offered will need to explicitly accept the credit.
+        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
         :param credited: iterable of dict with keys "login" and "type"
+
         """
         assert isinstance(credited, Iterable), credited
         for credit in credited:
-            RepositoryAdvisoryCredit._validate_credit(credit)
+            github.AdvisoryCredit.AdvisoryCredit._validate_credit(credit)
 
         patch_parameters = {
-            "credits": [RepositoryAdvisoryCredit._to_github_dict(credit) for credit in (self.credits + list(credited))]
+            "credits": [
+                github.AdvisoryCredit.AdvisoryCredit._to_github_dict(credit)
+                for credit in (self.credits + list(credited))
+            ]
         }
         headers, data = self._requester.requestJsonAndCheck(
             "PATCH",
@@ -266,7 +263,7 @@ class RepositoryAdvisory(NonCompletableGithubObject):
         description: Opt[str] = NotSet,
         severity_or_cvss_vector_string: Opt[str] = NotSet,
         cve_id: Opt[str] = NotSet,
-        vulnerabilities: Opt[Iterable[AdvisoryVulnerability]] = NotSet,
+        vulnerabilities: Opt[Iterable[AdvisoryVulnerabilityInput]] = NotSet,
         cwe_ids: Opt[Iterable[str]] = NotSet,
         credits: Opt[Iterable[Credit]] = NotSet,
         state: Opt[str] = NotSet,
@@ -283,15 +280,13 @@ class RepositoryAdvisory(NonCompletableGithubObject):
         assert vulnerabilities is NotSet or isinstance(vulnerabilities, Iterable), vulnerabilities
         if isinstance(vulnerabilities, Iterable):
             for vulnerability in vulnerabilities:
-                github.RepositoryAdvisoryVulnerability.RepositoryAdvisoryVulnerability._validate_vulnerability(
-                    vulnerability
-                )
+                github.AdvisoryVulnerability.AdvisoryVulnerability._validate_vulnerability(vulnerability)
         assert cwe_ids is NotSet or (
             isinstance(cwe_ids, Iterable) and all(isinstance(element, str) for element in cwe_ids)
         ), cwe_ids
         if isinstance(credits, Iterable):
             for credit in credits:
-                github.RepositoryAdvisoryCredit.RepositoryAdvisoryCredit._validate_credit(credit)
+                github.AdvisoryCredit.AdvisoryCredit._validate_credit(credit)
         assert state is NotSet or isinstance(state, str), state
         patch_parameters: dict[str, Any] = {}
         if summary is not NotSet:
@@ -307,14 +302,14 @@ class RepositoryAdvisory(NonCompletableGithubObject):
             patch_parameters["cve_id"] = cve_id
         if isinstance(vulnerabilities, Iterable):
             patch_parameters["vulnerabilities"] = [
-                github.RepositoryAdvisoryVulnerability.RepositoryAdvisoryVulnerability._to_github_dict(vulnerability)
+                github.AdvisoryVulnerability.AdvisoryVulnerability._to_github_dict(vulnerability)
                 for vulnerability in vulnerabilities
             ]
         if isinstance(cwe_ids, Iterable):
             patch_parameters["cwe_ids"] = list(cwe_ids)
         if isinstance(credits, Iterable):
             patch_parameters["credits"] = [
-                github.RepositoryAdvisoryCredit.RepositoryAdvisoryCredit._to_github_dict(credit) for credit in credits
+                github.AdvisoryCredit.AdvisoryCredit._to_github_dict(credit) for credit in credits
             ]
         if state is not NotSet:
             patch_parameters["state"] = state
@@ -328,8 +323,10 @@ class RepositoryAdvisory(NonCompletableGithubObject):
 
     def accept_report(self) -> None:
         """
-        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
         Accepts the advisory reported from an external reporter via private vulnerability reporting.
+
+        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
+
         """
         patch_parameters = {"state": "draft"}
         headers, data = self._requester.requestJsonAndCheck(
@@ -341,8 +338,10 @@ class RepositoryAdvisory(NonCompletableGithubObject):
 
     def publish(self) -> None:
         """
-        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
         Publishes the advisory.
+
+        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
+
         """
         patch_parameters = {"state": "published"}
         headers, data = self._requester.requestJsonAndCheck(
@@ -352,10 +351,24 @@ class RepositoryAdvisory(NonCompletableGithubObject):
         )
         self._useAttributes(data)
 
+    def request_cve(self) -> None:
+        """
+        Requests a CVE for the advisory.
+
+        :calls: `POST /repos/{owner}/{repo}/security-advisories/{ghsa_id}/cve <https://docs.github.com/en/rest/security-advisories/repository-advisories#request-a-cve-for-a-repository-security-advisory>`_
+
+        """
+        self._requester.requestJsonAndCheck(
+            "POST",
+            self.url + "/cve",
+        )
+
     def close(self) -> None:
         """
-        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
         Closes the advisory.
+
+        :calls: `PATCH /repos/{owner}/{repo}/security-advisories/:advisory_id <https://docs.github.com/en/rest/security-advisories/repository-advisories>`
+
         """
         patch_parameters = {"state": "closed"}
         headers, data = self._requester.requestJsonAndCheck(
@@ -371,6 +384,14 @@ class RepositoryAdvisory(NonCompletableGithubObject):
         if "closed_at" in attributes:  # pragma no branch
             assert attributes["closed_at"] is None or isinstance(attributes["closed_at"], str), attributes["closed_at"]
             self._closed_at = self._makeDatetimeAttribute(attributes["closed_at"])
+        if "collaborating_teams" in attributes:  # pragma no branch
+            self._collaborating_teams = self._makeListOfClassesAttribute(
+                github.Team.Team, attributes["collaborating_teams"]
+            )
+        if "collaborating_users" in attributes:  # pragma no branch
+            self._collaborating_users = self._makeListOfClassesAttribute(
+                github.NamedUser.NamedUser, attributes["collaborating_users"]
+            )
         if "created_at" in attributes:  # pragma no branch
             assert attributes["created_at"] is None or isinstance(attributes["created_at"], str), attributes[
                 "created_at"
@@ -378,51 +399,27 @@ class RepositoryAdvisory(NonCompletableGithubObject):
             self._created_at = self._makeDatetimeAttribute(attributes["created_at"])
         if "credits" in attributes:  # pragma no branch
             self._credits = self._makeListOfClassesAttribute(
-                RepositoryAdvisoryCredit,
+                github.AdvisoryCredit.AdvisoryCredit,
                 attributes["credits"],
             )
         if "credits_detailed" in attributes:  # pragma no branch
             self._credits_detailed = self._makeListOfClassesAttribute(
-                RepositoryAdvisoryCreditDetailed,
+                github.AdvisoryCreditDetailed.AdvisoryCreditDetailed,
                 attributes["credits_detailed"],
             )
-        if "cve_id" in attributes:  # pragma no branch
-            self._cve_id = self._makeStringAttribute(attributes["cve_id"])
         if "cwe_ids" in attributes:  # pragma no branch
             self._cwe_ids = self._makeListOfStringsAttribute(attributes["cwe_ids"])
-        if "cwes" in attributes:  # pragma no branch
-            self._cwes = self._makeListOfClassesAttribute(CWE, attributes["cwes"])
-        if "description" in attributes:  # pragma no branch
-            self._description = self._makeStringAttribute(attributes["description"])
-        if "ghsa_id" in attributes:  # pragma no branch
-            self._ghsa_id = self._makeStringAttribute(attributes["ghsa_id"])
-        if "html_url" in attributes:  # pragma no branch
-            self._html_url = self._makeStringAttribute(attributes["html_url"])
-        if "published_at" in attributes:  # pragma no branch
-            assert attributes["published_at"] is None or isinstance(attributes["published_at"], str), attributes[
-                "published_at"
-            ]
-            self._published_at = self._makeDatetimeAttribute(attributes["published_at"])
-        if "severity" in attributes:  # pragma no branch
-            self._severity = self._makeStringAttribute(attributes["severity"])
+        if "private_fork" in attributes:  # pragma no branch
+            self._private_fork = self._makeClassAttribute(github.Repository.Repository, attributes["private_fork"])
+        if "publisher" in attributes:  # pragma no branch
+            self._publisher = self._makeClassAttribute(github.NamedUser.NamedUser, attributes["publisher"])
         if "state" in attributes:  # pragma no branch
             self._state = self._makeStringAttribute(attributes["state"])
-        if "summary" in attributes:  # pragma no branch
-            self._summary = self._makeStringAttribute(attributes["summary"])
-        if "updated_at" in attributes:  # pragma no branch
-            assert attributes["updated_at"] is None or isinstance(attributes["updated_at"], str), attributes[
-                "updated_at"
-            ]
-            self._updated_at = self._makeDatetimeAttribute(attributes["updated_at"])
-        if "url" in attributes:  # pragma no branch
-            self._url = self._makeStringAttribute(attributes["url"])
-        if "vulnerabilities" in attributes:  # pragma no branch
+        if "submission" in attributes:  # pragma no branch
+            self._submission = self._makeDictAttribute(attributes["submission"])
+        if "vulnerabilities" in attributes:
             self._vulnerabilities = self._makeListOfClassesAttribute(
-                RepositoryAdvisoryVulnerability,
+                github.AdvisoryVulnerability.AdvisoryVulnerability,
                 attributes["vulnerabilities"],
             )
-        if "withdrawn_at" in attributes:  # pragma no branch
-            assert attributes["withdrawn_at"] is None or isinstance(attributes["withdrawn_at"], str), attributes[
-                "withdrawn_at"
-            ]
-            self._withdrawn_at = self._makeDatetimeAttribute(attributes["withdrawn_at"])
+        super()._useAttributes(attributes)
